@@ -1,7 +1,4 @@
-import six
-
-
 class DictType(dict):
     def __init__(self, init):
-        for k, v in six.iteritems(init):
+        for k, v in init.items():
             self[k] = v
